# Table of Contents

- [configuring-sap-build-integration](<./configuring-sap-build-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP Build Integration for SAP Discovery](<./SAP-Build-Integration-for-SAP-Discovery.md>)
  - [Overview](<./SAP-Build-Integration-for-SAP-Discovery/Overview.md>)
  - [Prerequisites](<./SAP-Build-Integration-for-SAP-Discovery/Prerequisites.md>)
  - [Step 1: Creating an SAP Build Process Automation Instance and Service Key](<./SAP-Build-Integration-for-SAP-Discovery/Step-1-Creating-an-SAP-Build-Process-Automation-Instance-and-Service-Key.md>)
  - [Step 2: Creating an SAP Cloud Management Service Instance and Service Key](<./SAP-Build-Integration-for-SAP-Discovery/Step-2-Creating-an-SAP-Cloud-Management-Service-Instance-and-Service-Key.md>)
  - [Step 3: Connecting SAP LeanIX to the SAP Build Instance](<./SAP-Build-Integration-for-SAP-Discovery/Step-3-Connecting-SAP-LeanIX-to-the-SAP-Build-Instance.md>)
  - [Linking Discovered Items to Fact Sheets](<./SAP-Build-Integration-for-SAP-Discovery/Linking-Discovered-Items-to-Fact-Sheets.md>)
  - [Viewing Synchronization Logs](<./SAP-Build-Integration-for-SAP-Discovery/Viewing-Synchronization-Logs.md>)
